#!/bin/sh
#
# create_zones.sh
# ---
# a shell script to ease the creating of SAN zoning configuration
# suitable for Cisco MDS switches.
# ---
# r0.1 March 2011, Gianpaolo Del Matto <delmatto@phunsites.net>
# Released as Freeware. No Warranties taken at all. Use at your own risk.
# More information at http://phaq.phunsites.net/?p=533
# ---
# usage:
# 1. retrieve fc WWN list from cisco UCS fabric interconnects
#	-> invoke this command:	show identity wwn | grep fc-fc
# 2. store retrieved list in script directory by the name of "wwnlist"
# 3. change the variables below to reflect your environment.
#	-> NOTE: Please use your storage systems _real_ WWPNs.
#                All data in the vars below is FAKE and not usable!
# 4. run the script by invoking /bin/sh create_zones.sh to create MDS config
#

# change storage name as needed
#
PRI_SAN_NAME=SAN-001
SEC_SAN_NAME=SAN-002


# change FC HBA identifiers as needed
#
PRI_HBA_NAME=fc0
SEC_HBA_NAME=fc1


# change FABRIC identifiers as needed
#
PRI_FABRIC_NAME=FABRIC_A
SEC_FABRIC_NAME=FABRIC_B


# change VSAN ID as needed
#
PRI_FABRIC_VSAN=101
SEC_FABRIC_VSAN=102


# set names and wwns for primary SAN storage processors
#
PRI_SAN_SP_A0=${PRI_SAN_NAME}_SP-A0
PRI_SAN_SP_A0_WWN=50:06:01:60:00:00:00:01

PRI_SAN_SP_A1=${PRI_SAN_NAME}_SP-A1
PRI_SAN_SP_A1_WWN=50:06:01:61:00:00:00:01

PRI_SAN_SP_B1=${PRI_SAN_NAME}_SP-B1
PRI_SAN_SP_B1_WWN=50:06:01:69:00:00:00:01

PRI_SAN_SP_B0=${PRI_SAN_NAME}_SP-B0
PRI_SAN_SP_B0_WWN=50:06:01:68:00:00:00:01


# set names and wwns for secondary SAN storage processors
#
SEC_SAN_SP_A0=${SEC_SAN_NAME}_SP-A0
SEC_SAN_SP_A0_WWN=50:06:01:60:00:00:00:02

SEC_SAN_SP_A1=${SEC_SAN_NAME}_SP-A1
SEC_SAN_SP_A1_WWN=50:06:01:61:00:00:00:02

SEC_SAN_SP_B0=${SEC_SAN_NAME}_SP-B0
SEC_SAN_SP_B0_WWN=50:06:01:68:00:00:00:02

SEC_SAN_SP_B1=${SEC_SAN_NAME}_SP-B1
SEC_SAN_SP_B1_WWN=50:06:01:69:00:00:00:02



echo "---------------------------------------------"
echo "- ZONE CONFIG FOR FIRST FABRIC              -"
echo "---------------------------------------------"
cat wwnlist | grep "${PRI_HBA_NAME}$" | while read line;
do
		HBA_WWN=`echo $line | awk '{ print $1 }'`
		HBA_HOST_NAME=`echo $line | cut -f4 -d/ | sed 's/ls-//g'`

		# echo $HBA_HOST_NAME with $HBA_WWN on $PRI_HBA_NAME ...

		# add new WWN to device-alias database
		#
cat << EOF
device-alias database
device-alias name ${HBA_HOST_NAME}_${PRI_HBA_NAME} pwwn ${HBA_WWN}
exit
device-alias commit
EOF


		# add SAN zones from HOST-HBA to the four storage processors
		#
cat << EOF
zone name ${PRI_SAN_SP_A0}__${HBA_HOST_NAME}_${PRI_HBA_NAME} vsan ${PRI_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${PRI_SAN_SP_A0_WWN}

zone name ${PRI_SAN_SP_B1}__${HBA_HOST_NAME}_${PRI_HBA_NAME} vsan ${PRI_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${PRI_SAN_SP_B1_WWN}

zone name ${SEC_SAN_SP_A0}__${HBA_HOST_NAME}_${PRI_HBA_NAME} vsan ${PRI_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${SEC_SAN_SP_A0_WWN}

zone name ${SEC_SAN_SP_B1}__${HBA_HOST_NAME}_${PRI_HBA_NAME} vsan ${PRI_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${SEC_SAN_SP_B1_WWN}

zoneset name ${PRI_FABRIC_NAME} vsan ${PRI_FABRIC_VSAN}
    member ${PRI_SAN_SP_A0}__${HBA_HOST_NAME}_${PRI_HBA_NAME}
    member ${PRI_SAN_SP_B1}__${HBA_HOST_NAME}_${PRI_HBA_NAME}
    member ${SEC_SAN_SP_A0}__${HBA_HOST_NAME}_${PRI_HBA_NAME}
    member ${SEC_SAN_SP_B1}__${HBA_HOST_NAME}_${PRI_HBA_NAME}
EOF

done







echo "---------------------------------------------"
echo "- ZONE CONFIG FOR SECOND FABRIC              -"
echo "---------------------------------------------"
cat wwnlist | grep "${SEC_HBA_NAME}$" | while read line;
do
		HBA_WWN=`echo $line | awk '{ print $1 }'`
		HBA_HOST_NAME=`echo $line | cut -f4 -d/ | sed 's/ls-//g'`

		# echo $HBA_HOST_NAME with $HBA_WWN on $PRI_HBA_NAME ...

		# add new WWN to device-alias database
		#
cat << EOF
device-alias database
device-alias name ${HBA_HOST_NAME}_${SEC_HBA_NAME} pwwn ${HBA_WWN}
exit
device-alias commit
EOF


		# add SAN zones from HOST-HBA to the four storage processors
		#
cat << EOF
zone name ${PRI_SAN_SP_A1}__${HBA_HOST_NAME}_${SEC_HBA_NAME} vsan ${SEC_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${PRI_SAN_SP_A1_WWN}

zone name ${PRI_SAN_SP_B0}__${HBA_HOST_NAME}_${SEC_HBA_NAME} vsan ${SEC_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${PRI_SAN_SP_B0_WWN}

zone name ${SEC_SAN_SP_A1}__${HBA_HOST_NAME}_${SEC_HBA_NAME} vsan ${SEC_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${SEC_SAN_SP_A1_WWN}

zone name ${SEC_SAN_SP_B0}__${HBA_HOST_NAME}_${SEC_HBA_NAME} vsan ${SEC_FABRIC_VSAN}
    member pwwn ${HBA_WWN}
    member pwwn ${SEC_SAN_SP_B0_WWN}

zoneset name ${SEC_FABRIC_NAME} vsan ${SEC_FABRIC_VSAN}
    member ${PRI_SAN_SP_A1}__${HBA_HOST_NAME}_${SEC_HBA_NAME}
    member ${PRI_SAN_SP_B0}__${HBA_HOST_NAME}_${SEC_HBA_NAME}
    member ${SEC_SAN_SP_A1}__${HBA_HOST_NAME}_${SEC_HBA_NAME}
    member ${SEC_SAN_SP_B0}__${HBA_HOST_NAME}_${SEC_HBA_NAME}
EOF

done
